import ipaddress
import markdown as md_package
from flask import Blueprint

bp = Blueprint('filters', __name__)

@bp.app_template_filter('markdown')
def markdown_filter(text):
    """Convert markdown text to HTML"""
    if text:
        return md_package.markdown(text, extensions=['tables', 'fenced_code'])
    return ""

@bp.app_template_filter('ip_network')
def ip_network_filter(cidr):
    """Convert a CIDR string to an IP network object"""
    try:
        return ipaddress.ip_network(cidr, strict=False)
    except ValueError:
        return None

@bp.app_template_filter('ip_address')
def ip_address_filter(ip):
    """Convert an IP string to an IP address object"""
    try:
        return ipaddress.ip_address(ip)
    except ValueError:
        return None

@bp.app_template_global('get_ip_network')
def get_ip_network(cidr):
    """Global function to get an IP network object from CIDR"""
    try:
        return ipaddress.ip_network(cidr, strict=False)
    except ValueError:
        return None 